@@ -1,22 +1,11 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
- * 
+/* === This file is part of Calamares - <https://calamares.io> ===
+ *
  *   SPDX-FileCopyrightText: 2014-2015 Teo Mrnjavac <teo@kde.org>
- *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
- *
+ *   SPDX-FileCopyrightText: 2017 Adriaan de Groot <groot@kde.org>
  *   SPDX-License-Identifier: GPL-3.0-or-later
- *   License-Filename: LICENSE
+ *
+ *   Calamares is Free Software: see the License-Identifier above.
+ *
  *
  */
 #ifndef CALAMARES_JOB_H
@@ -97,24 +86,37 @@ class DLLEXPORT Job : public QObject
     Q_OBJECT
 public:
     explicit Job( QObject* parent = nullptr );
-    virtual ~Job();
+    ~Job() override;
 
     /** @brief The job's (relative) weight.
      *
-     * The default implementation returns 1.0, which gives all jobs
+     * The default implementation returns 1, which gives all jobs
      * the same weight, so they advance the overall progress the same
      * amount. This is nonsense, since some jobs take much longer than
      * others; it's up to the individual jobs to say something about
      * how much work is (relatively) done.
+     *
+     * Since jobs are caused by **modules** from the sequence, the
+     * overall weight of the module is taken into account: its weight
+     * is divided among the jobs based on each jobs relative weight.
+     * This can be used in a module that runs a bunch of jobs to indicate
+     * which of the jobs is "heavy" and which is not.
      */
-    virtual qreal getJobWeight() const;
+    virtual int getJobWeight() const;
     /** @brief The human-readable name of this job
      *
      * This should be a very short statement of what the job does.
      * For status and state information, see prettyStatusMessage().
      */
     virtual QString prettyName() const = 0;
-    // TODO: Unused
+    /** @brief a longer human-readable description of what the job will do
+     *
+     * This **may** be used by view steps to fill in the summary
+     * messages for the summary page; at present, only the *partition*
+     * module does so.
+     *
+     * The default implementation returns an empty string.
+     */
     virtual QString prettyDescription() const;
     /** @brief A human-readable status for progress reporting
      *
