@@ -1,28 +1,16 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
  *   SPDX-FileCopyrightText: 2013-2016 Teo Mrnjavac <teo@kde.org>
  *   SPDX-FileCopyrightText: 2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
  *   Originally from Tomahawk, portions:
  *   SPDX-FileCopyrightText: 2010-2011 Christian Muehlhaeuser <muesli@tomahawk-player.org>
  *   SPDX-FileCopyrightText: 2010-2011 Leo Franchi <lfranchi@kde.org>
  *   SPDX-FileCopyrightText: 2010-2012 Jeff Mitchell <jeff@tomahawk-player.org>
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
- *
- *   SPDX-License-Identifier: GPL-3.0-or-later
- *   License-Filename: LICENSE
  *
  */
 
@@ -69,7 +57,7 @@ getStringList( const QVariantMap& map, const QString& key, const QStringList& d
     if ( map.contains( key ) )
     {
         auto v = map.value( key );
-        if ( v.type() == QVariant::StringList )
+        if ( v.canConvert( QMetaType::QStringList ) )
         {
             return v.toStringList();
         }
@@ -83,7 +71,7 @@ getInteger( const QVariantMap& map, const QString& key, qint64 d )
     if ( map.contains( key ) )
     {
         auto v = map.value( key );
-        return v.toString().toLongLong(nullptr, 0);
+        return v.toString().toLongLong( nullptr, 0 );
     }
     return d;
 }
@@ -94,7 +82,7 @@ getUnsignedInteger( const QVariantMap& map, const QString& key, quint64 d )
     if ( map.contains( key ) )
     {
         auto v = map.value( key );
-        return v.toString().toULongLong(nullptr, 0);
+        return v.toString().toULongLong( nullptr, 0 );
     }
     return d;
 }
