@@ -45,6 +45,8 @@ class UIDLLEXPORT ViewManager : public QAbstractListModel
 
     Q_PROPERTY( bool quitVisible READ quitVisible NOTIFY quitVisibleChanged FINAL )
 
+    Q_PROPERTY( bool backAndNextVisible READ backAndNextVisible NOTIFY backAndNextVisibleChanged FINAL )
+
     ///@brief Sides on which the ViewManager has side-panels
     Q_PROPERTY( Qt::Orientations panelSides READ panelSides WRITE setPanelSides MEMBER m_panelSides )
 
@@ -144,6 +146,10 @@ public Q_SLOTS:
         return m_backIcon;  ///< Name of the icon to show
     }
 
+    bool backAndNextVisible() const
+    {
+        return m_backAndNextVisible;  ///< Is the quit-button to be enabled
+    }
     /**
      * @brief Probably quit
      *
@@ -203,6 +209,7 @@ signals:
     void backEnabledChanged( bool ) const;
     void backLabelChanged( QString ) const;
     void backIconChanged( QString ) const;
+    void backAndNextVisibleChanged( bool ) const;
 
     void quitEnabledChanged( bool ) const;
     void quitLabelChanged( QString ) const;
@@ -217,6 +224,7 @@ private:
     void insertViewStep( int before, ViewStep* step );
     void updateButtonLabels();
     void updateCancelEnabled( bool enabled );
+    void updateBackAndNextVisibility( bool visible );
 
     inline bool currentStepValid() const { return ( 0 <= m_currentStep ) && ( m_currentStep < m_steps.length() ); }
 
@@ -236,6 +244,8 @@ private:
     QString m_backLabel;
     QString m_backIcon;
 
+    bool m_backAndNextVisible = true;
+
     bool m_quitEnabled = false;
     QString m_quitLabel;
     QString m_quitIcon;
