@@ -1,26 +1,18 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
- *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
+ *   SPDX-FileCopyrightText: 2014-2015 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef EXECUTIONVIEWSTEP_H
 #define EXECUTIONVIEWSTEP_H
 
 #include "ViewStep.h"
+#include "modulesystem/InstanceKey.h"
 
 #include <QStringList>
 
@@ -57,7 +49,7 @@ public:
 
     JobList jobs() const override;
 
-    void appendJobModuleInstanceKey( const QString& instanceKey );
+    void appendJobModuleInstanceKey( const ModuleSystem::InstanceKey& instanceKey );
 
 private:
     QWidget* m_widget;
@@ -65,7 +57,7 @@ private:
     QLabel* m_label;
     Slideshow* m_slideshow;
 
-    QStringList m_jobInstanceKeys;
+    QList< ModuleSystem::InstanceKey > m_jobInstanceKeys;
 
     void updateFromJobQueue( qreal percent, const QString& message );
 };
