@@ -1,21 +1,12 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
- *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2018, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
+ *   SPDX-FileCopyrightText: 2014-2015 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Slideshow.h"
@@ -126,11 +117,8 @@ SlideshowQML::loadQmlV2Complete()
             {
                 // We're alreay visible! Must have been slow QML loading, and we
                 // passed onActivate already. changeSlideShowState() locks
-                // the same mutex: we could set up a workaround to call
-                // changeSlideShowState() later after destruction of l.
-                //
-                l.unlock();
-                changeSlideShowState( Slideshow::Start );
+                // the same mutex: call changeSlideShowState() after l is dead.
+                QTimer::singleShot( 0, this, &SlideshowQML::startSlideShow );
             }
         }
     }
@@ -151,6 +139,13 @@ SlideshowQML::loadQmlV2Complete()
     }
 }
 
+void
+SlideshowQML::startSlideShow()
+{
+    changeSlideShowState( Slideshow::Start );
+}
+
+
 /*
  * Applies V1 and V2 QML activation / deactivation:
  *  - V1 loads the QML in @p widget on activation. Sets root object property
