@@ -1,19 +1,10 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2018, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef RESIZEFSJOB_H
@@ -42,7 +33,7 @@ class PLUGINDLLEXPORT ResizeFSJob : public Calamares::CppJob
 
 public:
     explicit ResizeFSJob( QObject* parent = nullptr );
-    virtual ~ResizeFSJob() override;
+    ~ResizeFSJob() override;
 
     QString prettyName() const override;
 
@@ -51,26 +42,13 @@ public:
     void setConfigurationMap( const QVariantMap& configurationMap ) override;
 
     /** @brief Is the configuration of this job valid? */
-    bool isValid() const
-    {
-        return ( !m_fsname.isEmpty() || !m_devicename.isEmpty() ) &&
-               m_size.isValid();
-    }
+    bool isValid() const { return ( !m_fsname.isEmpty() || !m_devicename.isEmpty() ) && m_size.isValid(); }
 
-    QString name() const
-    {
-        return m_fsname.isEmpty() ? m_devicename : m_fsname;
-    }
+    QString name() const { return m_fsname.isEmpty() ? m_devicename : m_fsname; }
 
-    PartitionSize size() const
-    {
-        return m_size;
-    }
+    PartitionSize size() const { return m_size; }
 
-    PartitionSize minimumSize() const
-    {
-        return m_atleast;
-    }
+    PartitionSize minimumSize() const { return m_atleast; }
 
 private:
     CalamaresUtils::Partition::KPMManager m_kpmcore;
@@ -80,7 +58,7 @@ private:
     QString m_devicename;
     bool m_required;
 
-    using PartitionMatch = QPair<Device*, Partition*>;
+    using PartitionMatch = QPair< Device*, Partition* >;
     /** @brief Find the configured FS */
     PartitionMatch findPartition();
 
@@ -90,4 +68,4 @@ private:
 
 CALAMARES_PLUGIN_FACTORY_DECLARATION( ResizeFSJobFactory )
 
-#endif // RESIZEFSJOB_H
+#endif  // RESIZEFSJOB_H
