@@ -18,170 +18,28 @@
 #include "utils/Logger.h"
 #include "utils/Retranslator.h"
 #include "utils/String.h"
+#include "utils/Variant.h"
 
 #include <QApplication>
 #include <QProcess>
 #include <QTimer>
 
-KeyboardModelsModel::KeyboardModelsModel( QObject* parent )
-    : QAbstractListModel( parent )
+/* Returns stringlist with suitable setxkbmap command-line arguments
+ * to set the given @p model.
+ */
+static inline QStringList
+xkbmap_model_args( const QString& model )
 {
-    detectModels();
+    QStringList r { "-model", model };
+    return r;
 }
 
-void
-KeyboardModelsModel::detectModels()
-{
-    beginResetModel();
-    const auto models = KeyboardGlobal::getKeyboardModels();
-    auto index = -1;
-    for ( const auto& key : models.keys() )
-    {
-        index++;
-        m_list << QMap< QString, QString > { { "label", key }, { "key", models[ key ] } };
-        if ( models[ key ] == "pc105" )
-        {
-            this->setCurrentIndex( index );
-        }
-    }
-    endResetModel();
-}
-
-void
-KeyboardModelsModel::refresh()
-{
-    m_list.clear();
-    setCurrentIndex( -1 );
-    detectModels();
-}
-
-QVariant
-KeyboardModelsModel::data( const QModelIndex& index, int role ) const
-{
-    if ( !index.isValid() )
-    {
-        return QVariant();
-    }
-    const auto item = m_list.at( index.row() );
-    return role == Qt::DisplayRole ? item[ "label" ] : item[ "key" ];
-}
-
-int
-KeyboardModelsModel::rowCount( const QModelIndex& ) const
-{
-    return m_list.count();
-}
-
-QHash< int, QByteArray >
-KeyboardModelsModel::roleNames() const
-{
-    return { { Qt::DisplayRole, "label" }, { Qt::UserRole, "key" } };
-}
-
-int
-KeyboardModelsModel::currentIndex() const
-{
-    return m_currentIndex;
-}
-
-const QMap< QString, QString >
-KeyboardModelsModel::item( const int& index ) const
-{
-    if ( index >= m_list.count() || index < 0 )
-    {
-        return QMap< QString, QString >();
-    }
-
-    return m_list.at( index );
-}
-
-const QMap< QString, QString >
-KeyboardVariantsModel::item( const int& index ) const
-{
-    if ( index >= m_list.count() || index < 0 )
-    {
-        return QMap< QString, QString >();
-    }
-
-    return m_list.at( index );
-}
-
-void
-KeyboardModelsModel::setCurrentIndex( const int& index )
-{
-    if ( index >= m_list.count() || index < 0 )
-    {
-        return;
-    }
-
-    m_currentIndex = index;
-    emit currentIndexChanged( m_currentIndex );
-}
-
-KeyboardVariantsModel::KeyboardVariantsModel( QObject* parent )
-    : QAbstractListModel( parent )
-{
-}
-
-int
-KeyboardVariantsModel::currentIndex() const
-{
-    return m_currentIndex;
-}
-
-void
-KeyboardVariantsModel::setCurrentIndex( const int& index )
-{
-    if ( index >= m_list.count() || index < 0 )
-    {
-        return;
-    }
-
-    m_currentIndex = index;
-    emit currentIndexChanged( m_currentIndex );
-}
-
-QVariant
-KeyboardVariantsModel::data( const QModelIndex& index, int role ) const
-{
-    if ( !index.isValid() )
-    {
-        return QVariant();
-    }
-    const auto item = m_list.at( index.row() );
-    return role == Qt::DisplayRole ? item[ "label" ] : item[ "key" ];
-}
-
-int
-KeyboardVariantsModel::rowCount( const QModelIndex& ) const
-{
-    return m_list.count();
-}
-
-QHash< int, QByteArray >
-KeyboardVariantsModel::roleNames() const
-{
-    return { { Qt::DisplayRole, "label" }, { Qt::UserRole, "key" } };
-}
-
-void
-KeyboardVariantsModel::setVariants( QMap< QString, QString > variants )
-{
-    m_list.clear();
-    beginResetModel();
-    for ( const auto& key : variants.keys() )
-    {
-        const auto item = QMap< QString, QString > { { "label", key }, { "key", variants[ key ] } };
-        m_list << item;
-    }
-    endResetModel();
-}
 
 /* Returns stringlist with suitable setxkbmap command-line arguments
  * to set the given @p layout and @p variant.
  */
 static inline QStringList
-xkbmap_args( const QString& layout, const QString& variant )
+xkbmap_layout_args( const QString& layout, const QString& variant )
 {
     QStringList r { "-layout", layout };
     if ( !variant.isEmpty() )
@@ -191,6 +49,103 @@ xkbmap_args( const QString& layout, const QString& variant )
     return r;
 }
 
+static inline QStringList
+xkbmap_layout_args( const QStringList& layouts,
+                    const QStringList& variants,
+                    const QString& switchOption = "grp:alt_shift_toggle" )
+{
+    if ( layouts.size() != variants.size() )
+    {
+        cError() << "Number of layouts and variants must be equal (empty string should be used if there is no "
+                    "corresponding variant)";
+        return QStringList();
+    }
+
+    QStringList r { "-layout", layouts.join( "," ) };
+
+    if ( !variants.isEmpty() )
+    {
+        r << "-variant" << variants.join( "," );
+    }
+
+    if ( !switchOption.isEmpty() )
+    {
+        r << "-option" << switchOption;
+    }
+
+    return r;
+}
+
+/* Returns group-switch setxkbd option if set
+ * or an empty string otherwise
+ */
+static inline QString
+xkbmap_query_grp_option()
+{
+    QProcess setxkbmapQuery;
+    setxkbmapQuery.start( "setxkbmap", { "-query" } );
+    setxkbmapQuery.waitForFinished();
+
+    QString outputLine;
+
+    do
+    {
+        outputLine = setxkbmapQuery.readLine();
+    } while ( setxkbmapQuery.canReadLine() && !outputLine.startsWith( "options:" ) );
+
+    if ( !outputLine.startsWith( "options:" ) )
+    {
+        return QString();
+    }
+
+    int index = outputLine.indexOf( "grp:" );
+
+    if ( index == -1 )
+    {
+        return QString();
+    }
+
+    //it's either in the end of line or before the other option so \s or ,
+    int lastIndex = outputLine.indexOf( QRegExp( "[\\s,]" ), index );
+
+    return outputLine.mid( index, lastIndex - index );
+}
+
+AdditionalLayoutInfo
+Config::getAdditionalLayoutInfo( const QString& layout )
+{
+    QFile layoutTable( ":/non-ascii-layouts" );
+
+    if ( !layoutTable.open( QIODevice::ReadOnly | QIODevice::Text ) )
+    {
+        cError() << "Non-ASCII layout table could not be opened";
+        return AdditionalLayoutInfo();
+    }
+
+    QString tableLine;
+
+    do
+    {
+        tableLine = layoutTable.readLine();
+    } while ( layoutTable.canReadLine() && !tableLine.startsWith( layout ) );
+
+    if ( !tableLine.startsWith( layout ) )
+    {
+        return AdditionalLayoutInfo();
+    }
+
+    QStringList tableEntries = tableLine.split( " ", SplitSkipEmptyParts );
+
+    AdditionalLayoutInfo r;
+
+    r.additionalLayout = tableEntries[ 1 ];
+    r.additionalVariant = tableEntries[ 2 ] == "-" ? "" : tableEntries[ 2 ];
+
+    r.vconsoleKeymap = tableEntries[ 3 ];
+
+    return r;
+}
+
 Config::Config( QObject* parent )
     : QObject( parent )
     , m_keyboardModelsModel( new KeyboardModelsModel( this ) )
@@ -201,9 +156,9 @@ Config::Config( QObject* parent )
 
     // Connect signals and slots
     connect( m_keyboardModelsModel, &KeyboardModelsModel::currentIndexChanged, [&]( int index ) {
-        m_selectedModel = m_keyboardModelsModel->item( index ).value( "key", "pc105" );
-        //                      Set Xorg keyboard model
-        QProcess::execute( "setxkbmap", QStringList { "-model", m_selectedModel } );
+        // Set Xorg keyboard model
+        m_selectedModel = m_keyboardModelsModel->key( index );
+        QProcess::execute( "setxkbmap", xkbmap_model_args( m_selectedModel ) );
         emit prettyStatusChanged();
     } );
 
@@ -214,9 +169,9 @@ Config::Config( QObject* parent )
     } );
 
     connect( m_keyboardVariantsModel, &KeyboardVariantsModel::currentIndexChanged, [&]( int index ) {
-        m_selectedVariant = m_keyboardVariantsModel->item( index )[ "key" ];
+        // Set Xorg keyboard layout + variant
+        m_selectedVariant = m_keyboardVariantsModel->key( index );
 
-        // Set Xorg keyboard layout
         if ( m_setxkbmapTimer.isActive() )
         {
             m_setxkbmapTimer.stop();
@@ -224,8 +179,32 @@ Config::Config( QObject* parent )
         }
 
         connect( &m_setxkbmapTimer, &QTimer::timeout, this, [=] {
-            QProcess::execute( "setxkbmap", xkbmap_args( m_selectedLayout, m_selectedVariant ) );
-            cDebug() << "xkbmap selection changed to: " << m_selectedLayout << '-' << m_selectedVariant;
+            m_additionalLayoutInfo = getAdditionalLayoutInfo( m_selectedLayout );
+
+            if ( !m_additionalLayoutInfo.additionalLayout.isEmpty() )
+            {
+                m_additionalLayoutInfo.groupSwitcher = xkbmap_query_grp_option();
+
+                if ( m_additionalLayoutInfo.groupSwitcher.isEmpty() )
+                {
+                    m_additionalLayoutInfo.groupSwitcher = "grp:alt_shift_toggle";
+                }
+
+                QProcess::execute( "setxkbmap",
+                                   xkbmap_layout_args( { m_additionalLayoutInfo.additionalLayout, m_selectedLayout },
+                                                       { m_additionalLayoutInfo.additionalVariant, m_selectedVariant },
+                                                       m_additionalLayoutInfo.groupSwitcher ) );
+
+
+                cDebug() << "xkbmap selection changed to: " << m_selectedLayout << '-' << m_selectedVariant << "(added "
+                         << m_additionalLayoutInfo.additionalLayout << "-" << m_additionalLayoutInfo.additionalVariant
+                         << " since current layout is not ASCII-capable)";
+            }
+            else
+            {
+                QProcess::execute( "setxkbmap", xkbmap_layout_args( m_selectedLayout, m_selectedVariant ) );
+                cDebug() << "xkbmap selection changed to: " << m_selectedLayout << '-' << m_selectedVariant;
+            }
             m_setxkbmapTimer.disconnect( this );
         } );
         m_setxkbmapTimer.start( QApplication::keyboardInputInterval() );
@@ -269,7 +248,7 @@ findLayout( const KeyboardLayoutModel* klm, const QString& currentLayout )
 }
 
 void
-Config::init()
+Config::detectCurrentKeyboardLayout()
 {
     //### Detect current keyboard layout and variant
     QString currentLayout;
@@ -281,18 +260,25 @@ Config::init()
     {
         const QStringList list = QString( process.readAll() ).split( "\n", SplitSkipEmptyParts );
 
-        for ( QString line : list )
+        // A typical line looks like
+        //      xkb_symbols   { include "pc+latin+ru:2+inet(evdev)+group(alt_shift_toggle)+ctrl(swapcaps)"       };
+        for ( const auto& line : list )
         {
-            line = line.trimmed();
-            if ( !line.startsWith( "xkb_symbols" ) )
+            if ( !line.trimmed().startsWith( "xkb_symbols" ) )
             {
                 continue;
             }
 
-            line = line.remove( "}" ).remove( "{" ).remove( ";" );
-            line = line.mid( line.indexOf( "\"" ) + 1 );
+            int firstQuote = line.indexOf( '"' );
+            int lastQuote = line.lastIndexOf( '"' );
 
-            QStringList split = line.split( "+", SplitSkipEmptyParts );
+            if ( firstQuote < 0 || lastQuote < 0 || lastQuote <= firstQuote )
+            {
+                continue;
+            }
+
+            QStringList split = line.mid( firstQuote + 1, lastQuote - firstQuote ).split( "+", SplitSkipEmptyParts );
+            cDebug() << split;
             if ( split.size() >= 2 )
             {
                 currentLayout = split.at( 1 );
@@ -338,11 +324,11 @@ Config::prettyStatus() const
 {
     QString status;
     status += tr( "Set keyboard model to %1.<br/>" )
-                  .arg( m_keyboardModelsModel->item( m_keyboardModelsModel->currentIndex() )[ "label" ] );
+                  .arg( m_keyboardModelsModel->label( m_keyboardModelsModel->currentIndex() ) );
 
     QString layout = m_keyboardLayoutsModel->item( m_keyboardLayoutsModel->currentIndex() ).second.description;
     QString variant = m_keyboardVariantsModel->currentIndex() >= 0
-        ? m_keyboardVariantsModel->item( m_keyboardVariantsModel->currentIndex() )[ "label" ]
+        ? m_keyboardVariantsModel->label( m_keyboardVariantsModel->currentIndex() )
         : QString( "<default>" );
     status += tr( "Set keyboard layout to %1/%2." ).arg( layout, variant );
 
@@ -350,16 +336,17 @@ Config::prettyStatus() const
 }
 
 Calamares::JobList
-Config::createJobs( const QString& xOrgConfFileName, const QString& convertedKeymapPath, bool writeEtcDefaultKeyboard )
+Config::createJobs()
 {
     QList< Calamares::job_ptr > list;
 
     Calamares::Job* j = new SetKeyboardLayoutJob( m_selectedModel,
                                                   m_selectedLayout,
                                                   m_selectedVariant,
-                                                  xOrgConfFileName,
-                                                  convertedKeymapPath,
-                                                  writeEtcDefaultKeyboard );
+                                                  m_additionalLayoutInfo,
+                                                  m_xOrgConfFileName,
+                                                  m_convertedKeymapPath,
+                                                  m_writeEtcDefaultKeyboard );
     list.append( Calamares::job_ptr( j ) );
 
     return list;
@@ -393,13 +380,12 @@ Config::guessLayout( const QStringList& langParts )
                 cDebug() << "Next level:" << *countryPart;
                 for ( int variantnumber = 0; variantnumber < m_keyboardVariantsModel->rowCount(); ++variantnumber )
                 {
-                    if ( m_keyboardVariantsModel->item( variantnumber )[ "key" ].compare( *countryPart,
-                                                                                          Qt::CaseInsensitive ) )
+                    if ( m_keyboardVariantsModel->key( variantnumber ).compare( *countryPart, Qt::CaseInsensitive )
+                         == 0 )
                     {
                         m_keyboardVariantsModel->setCurrentIndex( variantnumber );
-                        cDebug() << Logger::SubEntry << "matched variant"
-                                 << m_keyboardVariantsModel->item( variantnumber )[ "key" ] << ' '
-                                 << m_keyboardVariantsModel->item( variantnumber )[ "key" ];
+                        cDebug() << Logger::SubEntry << "matched variant" << *countryPart << ' '
+                                 << m_keyboardVariantsModel->key( variantnumber );
                     }
                 }
             }
@@ -507,6 +493,13 @@ Config::finalize()
     {
         gs->insert( "keyboardLayout", m_selectedLayout );
         gs->insert( "keyboardVariant", m_selectedVariant );  //empty means default variant
+
+        if ( !m_additionalLayoutInfo.additionalLayout.isEmpty() )
+        {
+            gs->insert( "keyboardAdditionalLayout", m_additionalLayoutInfo.additionalLayout );
+            gs->insert( "keyboardAdditionalLayout", m_additionalLayoutInfo.additionalVariant );
+            gs->insert( "keyboardVConsoleKeymap", m_additionalLayoutInfo.vconsoleKeymap );
+        }
     }
 
     //FIXME: also store keyboard model for something?
@@ -529,3 +522,47 @@ Config::updateVariants( const QPersistentModelIndex& currentItem, QString curren
         }
     }
 }
+
+void
+Config::setConfigurationMap( const QVariantMap& configurationMap )
+{
+    using namespace CalamaresUtils;
+
+    if ( configurationMap.contains( "xOrgConfFileName" )
+         && configurationMap.value( "xOrgConfFileName" ).type() == QVariant::String
+         && !getString( configurationMap, "xOrgConfFileName" ).isEmpty() )
+    {
+        m_xOrgConfFileName = getString( configurationMap, "xOrgConfFileName" );
+    }
+    else
+    {
+        m_xOrgConfFileName = "00-keyboard.conf";
+    }
+
+    if ( configurationMap.contains( "convertedKeymapPath" )
+         && configurationMap.value( "convertedKeymapPath" ).type() == QVariant::String
+         && !getString( configurationMap, "convertedKeymapPath" ).isEmpty() )
+    {
+        m_convertedKeymapPath = getString( configurationMap, "convertedKeymapPath" );
+    }
+    else
+    {
+        m_convertedKeymapPath = QString();
+    }
+
+    if ( configurationMap.contains( "writeEtcDefaultKeyboard" )
+         && configurationMap.value( "writeEtcDefaultKeyboard" ).type() == QVariant::Bool )
+    {
+        m_writeEtcDefaultKeyboard = getBool( configurationMap, "writeEtcDefaultKeyboard", true );
+    }
+    else
+    {
+        m_writeEtcDefaultKeyboard = true;
+    }
+}
+
+void
+Config::retranslate()
+{
+    retranslateKeyboardModels();
+}
