@@ -38,6 +38,7 @@ def mount_partition(root_mount_point, partition, partitions):
     """
     # Create mount point with `+` rather than `os.path.join()` because
     # `partition["mountPoint"]` starts with a '/'.
+    global_storage = libcalamares.globalstorage
     raw_mount_point = partition["mountPoint"]
     if not raw_mount_point:
         return
@@ -77,6 +78,7 @@ def mount_partition(root_mount_point, partition, partitions):
     # for the root mount point.
     # If a separate /home partition isn't defined, we also create
     # a subvolume "@home".
+    # If a swapfile is used, we also create a subvolume "@swap".
     # Finally we remount all of the above on the correct paths.
     if fstype == "btrfs" and partition["mountPoint"] == '/':
         has_home_mount_point = False
@@ -86,6 +88,12 @@ def mount_partition(root_mount_point, partition, partitions):
             if p["mountPoint"] == "/home":
                 has_home_mount_point = True
                 break
+        needs_swap_subvolume = False
+        swap_choice = global_storage.value( "partitionChoices" )
+        if swap_choice:
+            swap_choice = swap_choice.get( "swap", None )
+            if swap_choice and swap_choice == "file":
+                needs_swap_subvolume = True
 
         subprocess.check_call(['btrfs', 'subvolume', 'create',
                                root_mount_point + '/@'])
@@ -93,6 +101,9 @@ def mount_partition(root_mount_point, partition, partitions):
         if not has_home_mount_point:
             subprocess.check_call(['btrfs', 'subvolume', 'create',
                                    root_mount_point + '/@home'])
+        if needs_swap_subvolume:
+            subprocess.check_call(['btrfs', 'subvolume', 'create',
+                                       root_mount_point + '/@swap'])
 
         subprocess.check_call(["umount", "-v", root_mount_point])
 
@@ -113,6 +124,13 @@ def mount_partition(root_mount_point, partition, partitions):
                                         fstype,
                                         ",".join(["subvol=@home", partition.get("options", "")])) != 0:
                 libcalamares.utils.warning("Cannot mount {}".format(device))
+        
+        if needs_swap_subvolume:
+            if libcalamares.utils.mount(device,
+                                        root_mount_point + "/swap",
+                                        fstype,
+                                        ",".join(["subvol=@swap", partition.get("options", "")])) != 0:
+                libcalamares.utils.warning("Cannot mount {}".format(device))
 
 
 def run():
