@@ -110,8 +110,7 @@ PackageChooserViewStep::isNextEnabled() const
         // exactly one OR one or more
         return m_widget->hasSelection();
     }
-
-    NOTREACHED return true;
+    __builtin_unreachable();
 }
 
 
