@@ -1,26 +1,17 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
- *   Copyright 2015-2016, Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
+ *   SPDX-FileCopyrightText: 2015-2016 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "PartitionLabelsView.h"
 
-#include "core/PartitionModel.h"
 #include "core/ColorUtils.h"
+#include "core/PartitionModel.h"
 
 #include "utils/CalamaresUtilsGui.h"
 #include "utils/Logger.h"
@@ -39,8 +30,7 @@
 using CalamaresUtils::operator""_MiB;
 
 static const int LAYOUT_MARGIN = 4;
-static const int LABEL_PARTITION_SQUARE_MARGIN =
-        qMax( QFontMetrics( CalamaresUtils::defaultFont() ).ascent() - 2, 18 );
+static const int LABEL_PARTITION_SQUARE_MARGIN = qMax( QFontMetrics( CalamaresUtils::defaultFont() ).ascent() - 2, 18 );
 static const int LABELS_MARGIN = LABEL_PARTITION_SQUARE_MARGIN;
 static const int CORNER_RADIUS = 2;
 
@@ -63,14 +53,12 @@ PartitionLabelsView::PartitionLabelsView( QWidget* parent )
     setFrameStyle( QFrame::NoFrame );
     setSelectionBehavior( QAbstractItemView::SelectRows );
     setSelectionMode( QAbstractItemView::SingleSelection );
-    this->setObjectName("partitionLabel");
+    this->setObjectName( "partitionLabel" );
     setMouseTracking( true );
 }
 
 
-PartitionLabelsView::~PartitionLabelsView()
-{
-}
+PartitionLabelsView::~PartitionLabelsView() {}
 
 
 QSize
@@ -80,7 +68,6 @@ PartitionLabelsView::minimumSizeHint() const
 }
 
 
-
 QSize
 PartitionLabelsView::sizeHint() const
 {
@@ -150,7 +137,9 @@ PartitionLabelsView::getIndexesToDraw( const QModelIndex& parent ) const
 
     QAbstractItemModel* modl = model();
     if ( !modl )
+    {
         return list;
+    }
 
     for ( int row = 0; row < modl->rowCount( parent ); ++row )
     {
@@ -160,15 +149,21 @@ PartitionLabelsView::getIndexesToDraw( const QModelIndex& parent ) const
         //      To save vertical space, we choose to hide short instances of free space.
         //      Arbitrary limit: 10MiB.
         const qint64 maxHiddenB = 10_MiB;
-        if ( index.data( PartitionModel::IsFreeSpaceRole ).toBool() &&
-             index.data( PartitionModel::SizeRole ).toLongLong() <  maxHiddenB )
+        if ( index.data( PartitionModel::IsFreeSpaceRole ).toBool()
+             && index.data( PartitionModel::SizeRole ).toLongLong() < maxHiddenB )
+        {
             continue;
+        }
 
         if ( !modl->hasChildren( index ) || !m_extendedPartitionHidden )
+        {
             list.append( index );
+        }
 
         if ( modl->hasChildren( index ) )
+        {
             list.append( getIndexesToDraw( index ) );
+        }
     }
     return list;
 }
@@ -189,64 +184,74 @@ PartitionLabelsView::buildTexts( const QModelIndex& index ) const
         }
         else
         {
-            QString mountPoint = index.sibling( index.row(),
-                                                PartitionModel::MountPointColumn )
-                                      .data().toString();
+            QString mountPoint = index.sibling( index.row(), PartitionModel::MountPointColumn ).data().toString();
             if ( mountPoint == "/" )
-                firstLine = m_customNewRootLabel.isEmpty() ?
-                                tr( "Root" ) :
-                                m_customNewRootLabel;
+            {
+                firstLine = m_customNewRootLabel.isEmpty() ? tr( "Root" ) : m_customNewRootLabel;
+            }
             else if ( mountPoint == "/home" )
+            {
                 firstLine = tr( "Home" );
+            }
             else if ( mountPoint == "/boot" )
+            {
                 firstLine = tr( "Boot" );
-            else if ( mountPoint.contains( "/efi" ) &&
-                      index.data( PartitionModel::FileSystemTypeRole ).toInt() == FileSystem::Fat32 )
+            }
+            else if ( mountPoint.contains( "/efi" )
+                      && index.data( PartitionModel::FileSystemTypeRole ).toInt() == FileSystem::Fat32 )
+            {
                 firstLine = tr( "EFI system" );
+            }
             else if ( index.data( PartitionModel::FileSystemTypeRole ).toInt() == FileSystem::LinuxSwap )
+            {
                 firstLine = tr( "Swap" );
+            }
             else if ( !mountPoint.isEmpty() )
+            {
                 firstLine = tr( "New partition for %1" ).arg( mountPoint );
+            }
             else
+            {
                 firstLine = tr( "New partition" );
+            }
         }
     }
     else if ( index.data( PartitionModel::OsproberNameRole ).toString().isEmpty() )
     {
         firstLine = index.data().toString();
         if ( firstLine.startsWith( "/dev/" ) )
-            firstLine.remove( 0, 5 );   // "/dev/"
+        {
+            firstLine.remove( 0, 5 );  // "/dev/"
+        }
     }
     else
+    {
         firstLine = index.data( PartitionModel::OsproberNameRole ).toString();
+    }
 
-    if ( index.data( PartitionModel::IsFreeSpaceRole ).toBool() ||
-         index.data( PartitionModel::FileSystemTypeRole ).toInt() == FileSystem::Extended )
-        secondLine = index.sibling( index.row(),
-                                    PartitionModel::SizeColumn )
-                          .data().toString();
+    if ( index.data( PartitionModel::IsFreeSpaceRole ).toBool()
+         || index.data( PartitionModel::FileSystemTypeRole ).toInt() == FileSystem::Extended )
+    {
+        secondLine = index.sibling( index.row(), PartitionModel::SizeColumn ).data().toString();
+    }
     else
         //: size[number]  filesystem[name]
         secondLine = tr( "%1  %2" )
-                     .arg( index.sibling( index.row(),
-                                          PartitionModel::SizeColumn )
-                                .data().toString() )
-                     .arg( index.sibling( index.row(),
-                                          PartitionModel::FileSystemColumn )
-                                .data().toString() );
+                         .arg( index.sibling( index.row(), PartitionModel::SizeColumn ).data().toString() )
+                         .arg( index.sibling( index.row(), PartitionModel::FileSystemColumn ).data().toString() );
 
     return { firstLine, secondLine };
 }
 
 
 void
-PartitionLabelsView::drawLabels( QPainter* painter,
-                                 const QRect& rect,
-                                 const QModelIndex& parent )
+PartitionLabelsView::drawLabels( QPainter* painter, const QRect& rect, const QModelIndex& parent )
 {
     PartitionModel* modl = qobject_cast< PartitionModel* >( model() );
     if ( !modl )
+    {
         return;
+    }
 
     const QModelIndexList indexesToDraw = getIndexesToDraw( parent );
 
@@ -260,20 +265,19 @@ PartitionLabelsView::drawLabels( QPainter* painter,
 
         QColor labelColor = index.data( Qt::DecorationRole ).value< QColor >();
 
-        if ( label_x + labelSize.width() > rect.width() ) //wrap to new line if overflow
+        if ( label_x + labelSize.width() > rect.width() )  //wrap to new line if overflow
         {
             label_x = rect.x();
             label_y += labelSize.height() + labelSize.height() / 4;
         }
 
         // Draw hover
-        if ( selectionMode() != QAbstractItemView::NoSelection && // no hover without selection
-             m_hoveredIndex.isValid() &&
-             index == m_hoveredIndex )
+        if ( selectionMode() != QAbstractItemView::NoSelection &&  // no hover without selection
+             m_hoveredIndex.isValid() && index == m_hoveredIndex )
         {
             painter->save();
             QRect labelRect( QPoint( label_x, label_y ), labelSize );
-            labelRect.adjust( 0, -LAYOUT_MARGIN, 0, -2*LAYOUT_MARGIN );
+            labelRect.adjust( 0, -LAYOUT_MARGIN, 0, -2 * LAYOUT_MARGIN );
             painter->translate( 0.5, 0.5 );
             QRect hoverRect = labelRect.adjusted( 0, 0, -1, -1 );
             painter->setBrush( QPalette().window().color().lighter( 102 ) );
@@ -285,19 +289,15 @@ PartitionLabelsView::drawLabels( QPainter* painter,
         }
 
         // Is this element the selected one?
-        bool sel = selectionMode() != QAbstractItemView::NoSelection &&
-                   index.isValid() &&
-                   selectionModel() &&
-                   !selectionModel()->selectedIndexes().isEmpty() &&
-                   selectionModel()->selectedIndexes().first() == index;
+        bool sel = selectionMode() != QAbstractItemView::NoSelection && index.isValid() && selectionModel()
+            && !selectionModel()->selectedIndexes().isEmpty() && selectionModel()->selectedIndexes().first() == index;
 
         drawLabel( painter, texts, labelColor, QPoint( label_x, label_y ), sel );
 
         label_x += labelSize.width() + LABELS_MARGIN;
     }
 
-    if ( !modl->rowCount() &&
-         !modl->device()->partitionTable() ) // No disklabel or unknown
+    if ( !modl->rowCount() && !modl->device()->partitionTable() )  // No disklabel or unknown
     {
         QStringList texts = buildUnknownDisklabelTexts( modl->device() );
         QColor labelColor = ColorUtils::unknownDisklabelColor();
@@ -311,7 +311,9 @@ PartitionLabelsView::sizeForAllLabels( int maxLineWidth ) const
 {
     PartitionModel* modl = qobject_cast< PartitionModel* >( model() );
     if ( !modl )
+    {
         return QSize();
+    }
 
     const QModelIndexList indexesToDraw = getIndexesToDraw( QModelIndex() );
 
@@ -337,15 +339,12 @@ PartitionLabelsView::sizeForAllLabels( int maxLineWidth ) const
         singleLabelHeight = qMax( singleLabelHeight, labelSize.height() );
     }
 
-    if ( !modl->rowCount() &&
-         !modl->device()->partitionTable() ) // Unknown or no disklabel
+    if ( !modl->rowCount() && !modl->device()->partitionTable() )  // Unknown or no disklabel
     {
-        singleLabelHeight = sizeForLabel( buildUnknownDisklabelTexts( modl->device() ) )
-                            .height();
+        singleLabelHeight = sizeForLabel( buildUnknownDisklabelTexts( modl->device() ) ).height();
     }
 
-    int totalHeight = numLines * singleLabelHeight +
-                      ( numLines - 1 ) * singleLabelHeight / 4; //spacings
+    int totalHeight = numLines * singleLabelHeight + ( numLines - 1 ) * singleLabelHeight / 4;  //spacings
 
     return QSize( maxLineWidth, totalHeight );
 }
@@ -363,7 +362,7 @@ PartitionLabelsView::sizeForLabel( const QStringList& text ) const
         vertOffset += textSize.height();
         width = qMax( width, textSize.width() );
     }
-    width += LABEL_PARTITION_SQUARE_MARGIN; //for the color square
+    width += LABEL_PARTITION_SQUARE_MARGIN;  //for the color square
     return QSize( width, vertOffset );
 }
 
@@ -381,22 +380,21 @@ PartitionLabelsView::drawLabel( QPainter* painter,
     for ( const QString& textLine : text )
     {
         QSize textSize = painter->fontMetrics().size( Qt::TextSingleLine, textLine );
-        painter->drawText( pos.x()+LABEL_PARTITION_SQUARE_MARGIN,
-                           pos.y() + vertOffset + textSize.height() / 2,
-                           textLine );
+        painter->drawText(
+            pos.x() + LABEL_PARTITION_SQUARE_MARGIN, pos.y() + vertOffset + textSize.height() / 2, textLine );
         vertOffset += textSize.height();
         painter->setPen( Qt::gray );
         width = qMax( width, textSize.width() );
     }
 
-    QRect partitionSquareRect( pos.x(),
-                               pos.y() - 3,
-                               LABEL_PARTITION_SQUARE_MARGIN - 5,
-                               LABEL_PARTITION_SQUARE_MARGIN - 5 );
+    QRect partitionSquareRect(
+        pos.x(), pos.y() - 3, LABEL_PARTITION_SQUARE_MARGIN - 5, LABEL_PARTITION_SQUARE_MARGIN - 5 );
     drawPartitionSquare( painter, partitionSquareRect, color );
 
     if ( selected )
+    {
         drawSelectionSquare( painter, partitionSquareRect.adjusted( 2, 2, -2, -2 ), color );
+    }
 
     painter->setPen( Qt::black );
 }
@@ -407,7 +405,9 @@ PartitionLabelsView::indexAt( const QPoint& point ) const
 {
     PartitionModel* modl = qobject_cast< PartitionModel* >( model() );
     if ( !modl )
+    {
         return QModelIndex();
+    }
 
     const QModelIndexList indexesToDraw = getIndexesToDraw( QModelIndex() );
 
@@ -420,7 +420,7 @@ PartitionLabelsView::indexAt( const QPoint& point ) const
 
         QSize labelSize = sizeForLabel( texts );
 
-        if ( label_x + labelSize.width() > rect.width() ) //wrap to new line if overflow
+        if ( label_x + labelSize.width() > rect.width() )  //wrap to new line if overflow
         {
             label_x = rect.x();
             label_y += labelSize.height() + labelSize.height() / 4;
@@ -428,7 +428,9 @@ PartitionLabelsView::indexAt( const QPoint& point ) const
 
         QRect labelRect( QPoint( label_x, label_y ), labelSize );
         if ( labelRect.contains( point ) )
+        {
             return index;
+        }
 
         label_x += labelSize.width() + LABELS_MARGIN;
     }
@@ -442,7 +444,9 @@ PartitionLabelsView::visualRect( const QModelIndex& idx ) const
 {
     PartitionModel* modl = qobject_cast< PartitionModel* >( model() );
     if ( !modl )
+    {
         return QRect();
+    }
 
     const QModelIndexList indexesToDraw = getIndexesToDraw( QModelIndex() );
 
@@ -455,14 +459,16 @@ PartitionLabelsView::visualRect( const QModelIndex& idx ) const
 
         QSize labelSize = sizeForLabel( texts );
 
-        if ( label_x + labelSize.width() > rect.width() ) //wrap to new line if overflow
+        if ( label_x + labelSize.width() > rect.width() )  //wrap to new line if overflow
         {
             label_x = rect.x();
             label_y += labelSize.height() + labelSize.height() / 4;
         }
 
         if ( idx.isValid() && idx == index )
+        {
             return QRect( QPoint( label_x, label_y ), labelSize );
+        }
 
         label_x += labelSize.width() + LABELS_MARGIN;
     }
@@ -514,11 +520,7 @@ void
 PartitionLabelsView::setSelectionModel( QItemSelectionModel* selectionModel )
 {
     QAbstractItemView::setSelectionModel( selectionModel );
-    connect( selectionModel, &QItemSelectionModel::selectionChanged,
-             this, [=]
-    {
-        viewport()->repaint();
-    } );
+    connect( selectionModel, &QItemSelectionModel::selectionChanged, this, [=] { viewport()->repaint(); } );
 }
 
 
@@ -560,7 +562,9 @@ PartitionLabelsView::setSelection( const QRect& rect, QItemSelectionModel::Selec
 {
     QModelIndex eventIndex = indexAt( rect.topLeft() );
     if ( m_canBeSelected( eventIndex ) )
+    {
         selectionModel()->select( eventIndex, flags );
+    }
 }
 
 
@@ -582,9 +586,13 @@ PartitionLabelsView::mouseMoveEvent( QMouseEvent* event )
     if ( oldHoveredIndex != m_hoveredIndex )
     {
         if ( m_hoveredIndex.isValid() && !m_canBeSelected( m_hoveredIndex ) )
+        {
             QGuiApplication::setOverrideCursor( Qt::ForbiddenCursor );
+        }
         else
+        {
             QGuiApplication::restoreOverrideCursor();
+        }
 
         viewport()->repaint();
     }
@@ -610,14 +618,18 @@ PartitionLabelsView::mousePressEvent( QMouseEvent* event )
 {
     QModelIndex candidateIndex = indexAt( event->pos() );
     if ( m_canBeSelected( candidateIndex ) )
+    {
         QAbstractItemView::mousePressEvent( event );
+    }
     else
+    {
         event->accept();
+    }
 }
 
 
 void
 PartitionLabelsView::updateGeometries()
 {
-    updateGeometry(); //get a new rect() for redrawing all the labels
+    updateGeometry();  //get a new rect() for redrawing all the labels
 }
