@@ -1,24 +1,15 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
- *   Copyright 2015-2016, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2018-2019, Adriaan de Groot <groot@kde.org>
- *   Copyright 2018, Andrius Štikonas <andrius@stikonas.eu>
- *   Copyright 2018, Caio Jordão Carvalho <caiojcarvalho@gmail.com>
- *   Copyright 2019, Collabora Ltd
+ *   SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
+ *   SPDX-FileCopyrightText: 2015-2016 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2018-2019 Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2018 Andrius Štikonas <andrius@stikonas.eu>
+ *   SPDX-FileCopyrightText: 2018 Caio Jordão Carvalho <caiojcarvalho@gmail.com>
+ *   SPDX-FileCopyrightText: 2019 Collabora Ltd
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "PartitionPage.h"
@@ -26,19 +17,19 @@
 // Local
 #include "core/BootLoaderModel.h"
 #include "core/DeviceModel.h"
+#include "core/KPMHelpers.h"
+#include "core/PartUtils.h"
 #include "core/PartitionCoreModule.h"
 #include "core/PartitionInfo.h"
 #include "core/PartitionModel.h"
-#include "core/PartUtils.h"
-#include "core/KPMHelpers.h"
 #include "gui/CreatePartitionDialog.h"
 #include "gui/CreateVolumeGroupDialog.h"
 #include "gui/EditExistingPartitionDialog.h"
 #include "gui/ResizeVolumeGroupDialog.h"
 #include "gui/ScanningDialog.h"
 
-#include "ui_PartitionPage.h"
 #include "ui_CreatePartitionTableDialog.h"
+#include "ui_PartitionPage.h"
 
 #include "GlobalStorage.h"
 #include "JobQueue.h"
@@ -58,34 +49,34 @@
 #include <kpmcore/ops/removevolumegroupoperation.h>
 
 // Qt
+#include <QDir>
+#include <QFutureWatcher>
 #include <QHeaderView>
 #include <QItemSelectionModel>
 #include <QMessageBox>
 #include <QPointer>
-#include <QDir>
-#include <QFutureWatcher>
 #include <QtConcurrent/QtConcurrent>
 
 PartitionPage::PartitionPage( PartitionCoreModule* core, QWidget* parent )
     : QWidget( parent )
     , m_ui( new Ui_PartitionPage )
     , m_core( core )
-    , m_lastSelectedBootLoaderIndex(-1)
+    , m_lastSelectedBootLoaderIndex( -1 )
     , m_isEfi( false )
 {
     m_isEfi = PartUtils::isEfiSystem();
 
     m_ui->setupUi( this );
     m_ui->partitionLabelsView->setVisible(
-            Calamares::JobQueue::instance()->globalStorage()->
-                    value( "alwaysShowPartitionLabels" ).toBool() );
+        Calamares::JobQueue::instance()->globalStorage()->value( "alwaysShowPartitionLabels" ).toBool() );
     m_ui->deviceComboBox->setModel( m_core->deviceModel() );
     m_ui->bootLoaderComboBox->setModel( m_core->bootLoaderModel() );
-    connect( m_core->bootLoaderModel(), &QAbstractItemModel::modelReset, this, &PartitionPage::restoreSelectedBootLoader );
-    PartitionBarsView::NestedPartitionsMode mode = Calamares::JobQueue::instance()->globalStorage()->
-                                                   value( "drawNestedPartitions" ).toBool() ?
-                                                       PartitionBarsView::DrawNestedPartitions :
-                                                       PartitionBarsView::NoNestedPartitions;
+    connect(
+        m_core->bootLoaderModel(), &QAbstractItemModel::modelReset, this, &PartitionPage::restoreSelectedBootLoader );
+    PartitionBarsView::NestedPartitionsMode mode
+        = Calamares::JobQueue::instance()->globalStorage()->value( "drawNestedPartitions" ).toBool()
+        ? PartitionBarsView::DrawNestedPartitions
+        : PartitionBarsView::NoNestedPartitions;
     m_ui->partitionBarsView->setNestedPartitionsMode( mode );
     updateButtons();
     updateBootLoaderInstallPath();
@@ -93,23 +84,35 @@ PartitionPage::PartitionPage( PartitionCoreModule* core, QWidget* parent )
     updateFromCurrentDevice();
 
     connect( m_ui->deviceComboBox, &QComboBox::currentTextChanged, this, &PartitionPage::updateFromCurrentDevice );
-    connect( m_ui->bootLoaderComboBox, QOverload<int>::of(&QComboBox::activated), this, &PartitionPage::updateSelectedBootLoaderIndex );
-    connect( m_ui->bootLoaderComboBox, &QComboBox::currentTextChanged, this, &PartitionPage::updateBootLoaderInstallPath );
+    connect( m_ui->bootLoaderComboBox,
+             QOverload< int >::of( &QComboBox::activated ),
+             this,
+             &PartitionPage::updateSelectedBootLoaderIndex );
+    connect(
+        m_ui->bootLoaderComboBox, &QComboBox::currentTextChanged, this, &PartitionPage::updateBootLoaderInstallPath );
 
     connect( m_core, &PartitionCoreModule::isDirtyChanged, m_ui->revertButton, &QWidget::setEnabled );
 
-    connect( m_ui->partitionTreeView, &QAbstractItemView::doubleClicked, this, &PartitionPage::onPartitionViewActivated );
+    connect(
+        m_ui->partitionTreeView, &QAbstractItemView::doubleClicked, this, &PartitionPage::onPartitionViewActivated );
     connect( m_ui->revertButton, &QAbstractButton::clicked, this, &PartitionPage::onRevertClicked );
     connect( m_ui->newVolumeGroupButton, &QAbstractButton::clicked, this, &PartitionPage::onNewVolumeGroupClicked );
-    connect( m_ui->resizeVolumeGroupButton, &QAbstractButton::clicked, this, &PartitionPage::onResizeVolumeGroupClicked );
-    connect( m_ui->deactivateVolumeGroupButton, &QAbstractButton::clicked, this, &PartitionPage::onDeactivateVolumeGroupClicked );
-    connect( m_ui->removeVolumeGroupButton, &QAbstractButton::clicked, this, &PartitionPage::onRemoveVolumeGroupClicked );
-    connect( m_ui->newPartitionTableButton, &QAbstractButton::clicked, this, &PartitionPage::onNewPartitionTableClicked );
+    connect(
+        m_ui->resizeVolumeGroupButton, &QAbstractButton::clicked, this, &PartitionPage::onResizeVolumeGroupClicked );
+    connect( m_ui->deactivateVolumeGroupButton,
+             &QAbstractButton::clicked,
+             this,
+             &PartitionPage::onDeactivateVolumeGroupClicked );
+    connect(
+        m_ui->removeVolumeGroupButton, &QAbstractButton::clicked, this, &PartitionPage::onRemoveVolumeGroupClicked );
+    connect(
+        m_ui->newPartitionTableButton, &QAbstractButton::clicked, this, &PartitionPage::onNewPartitionTableClicked );
     connect( m_ui->createButton, &QAbstractButton::clicked, this, &PartitionPage::onCreateClicked );
     connect( m_ui->editButton, &QAbstractButton::clicked, this, &PartitionPage::onEditClicked );
     connect( m_ui->deleteButton, &QAbstractButton::clicked, this, &PartitionPage::onDeleteClicked );
 
-    if ( m_isEfi ) {
+    if ( m_isEfi )
+    {
         m_ui->bootLoaderComboBox->hide();
         m_ui->label_3->hide();
     }
@@ -117,14 +120,13 @@ PartitionPage::PartitionPage( PartitionCoreModule* core, QWidget* parent )
     CALAMARES_RETRANSLATE( m_ui->retranslateUi( this ); )
 }
 
-PartitionPage::~PartitionPage()
-{
-}
+PartitionPage::~PartitionPage() {}
 
 void
 PartitionPage::updateButtons()
 {
-    bool create = false, createTable = false, edit = false, del = false, currentDeviceIsVG = false, isDeactivable = false;
+    bool create = false, createTable = false, edit = false, del = false, currentDeviceIsVG = false,
+         isDeactivable = false;
     bool isRemovable = false, isVGdeactivated = false;
 
     QModelIndex index = m_ui->partitionTreeView->currentIndex();
@@ -157,16 +159,20 @@ PartitionPage::updateButtons()
         Device* device = nullptr;
         QModelIndex deviceIndex = m_core->deviceModel()->index( m_ui->deviceComboBox->currentIndex(), 0 );
         if ( deviceIndex.isValid() )
+        {
             device = m_core->deviceModel()->deviceForIndex( deviceIndex );
+        }
         if ( !device )
+        {
             cWarning() << "Device for updateButtons is nullptr";
+        }
         else if ( device->type() != Device::Type::LVM_Device )
         {
             createTable = true;
 
 #ifdef WITH_KPMCORE4API
-            if ( device->type() == Device::Type::SoftwareRAID_Device &&
-                 static_cast< SoftwareRAID* >(device)->status() == SoftwareRAID::Status::Inactive )
+            if ( device->type() == Device::Type::SoftwareRAID_Device
+                 && static_cast< SoftwareRAID* >( device )->status() == SoftwareRAID::Status::Inactive )
             {
                 createTable = false;
                 create = false;
@@ -177,7 +183,7 @@ PartitionPage::updateButtons()
         {
             currentDeviceIsVG = true;
 
-            LvmDevice* lvmDevice = dynamic_cast<LvmDevice*>(m_core->deviceModel()->deviceForIndex( deviceIndex ));
+            LvmDevice* lvmDevice = dynamic_cast< LvmDevice* >( m_core->deviceModel()->deviceForIndex( deviceIndex ) );
 
             isDeactivable = DeactivateVolumeGroupOperation::isDeactivatable( lvmDevice );
             isRemovable = RemoveVolumeGroupOperation::isRemovable( lvmDevice );
@@ -185,7 +191,9 @@ PartitionPage::updateButtons()
             isVGdeactivated = m_core->isVGdeactivated( lvmDevice );
 
             if ( isVGdeactivated )
+            {
                 m_ui->revertButton->setEnabled( true );
+            }
         }
     }
 
@@ -205,14 +213,18 @@ PartitionPage::onNewPartitionTableClicked()
     Q_ASSERT( index.isValid() );
     Device* device = m_core->deviceModel()->deviceForIndex( index );
 
-    QPointer<QDialog> dlg = new QDialog( this );
+    QPointer< QDialog > dlg = new QDialog( this );
     Ui_CreatePartitionTableDialog ui;
     ui.setupUi( dlg.data() );
     QString areYouSure = tr( "Are you sure you want to create a new partition table on %1?" ).arg( device->name() );
     if ( PartUtils::isEfiSystem() )
+    {
         ui.gptRadioButton->setChecked( true );
+    }
     else
+    {
         ui.mbrRadioButton->setChecked( true );
+    }
 
     ui.areYouSureLabel->setText( areYouSure );
     if ( dlg->exec() == QDialog::Accepted )
@@ -231,22 +243,27 @@ PartitionPage::checkCanCreate( Device* device )
 {
     auto table = device->partitionTable();
 
-    if ( table->type() == PartitionTable::msdos ||table->type() == PartitionTable::msdos_sectorbased )
+    if ( table->type() == PartitionTable::msdos || table->type() == PartitionTable::msdos_sectorbased )
     {
         cDebug() << "Checking MSDOS partition" << table->numPrimaries() << "primaries, max" << table->maxPrimaries();
 
         if ( ( table->numPrimaries() >= table->maxPrimaries() ) && !table->hasExtended() )
         {
-            QMessageBox::warning( this, tr( "Can not create new partition" ),
+            QMessageBox::warning(
+                this,
+                tr( "Can not create new partition" ),
                 tr( "The partition table on %1 already has %2 primary partitions, and no more can be added. "
-                    "Please remove one primary partition and add an extended partition, instead." ).arg( device->name() ).arg( table->numPrimaries() )
-            );
+                    "Please remove one primary partition and add an extended partition, instead." )
+                    .arg( device->name() )
+                    .arg( table->numPrimaries() ) );
             return false;
         }
         return true;
     }
     else
+    {
         return true;  // GPT is fine
+    }
 }
 
 void
@@ -260,13 +277,12 @@ PartitionPage::onNewVolumeGroupClicked()
 
     for ( const Partition* p : m_core->lvmPVs() )
         if ( !m_core->isInVG( p ) )
+        {
             availablePVs << p;
+        }
 
-    QPointer< CreateVolumeGroupDialog > dlg = new CreateVolumeGroupDialog( vgName,
-                                                                           selectedPVs,
-                                                                           availablePVs,
-                                                                           peSize,
-                                                                           this );
+    QPointer< CreateVolumeGroupDialog > dlg
+        = new CreateVolumeGroupDialog( vgName, selectedPVs, availablePVs, peSize, this );
 
     if ( dlg->exec() == QDialog::Accepted )
     {
@@ -282,7 +298,9 @@ PartitionPage::onNewVolumeGroupClicked()
             // Disable delete button if current partition was selected to be in VG
             // TODO: Should Calamares edit LVM PVs which are in VGs?
             if ( selectedPVs.contains( partition ) )
+            {
                 m_ui->deleteButton->setEnabled( false );
+            }
         }
 
         QModelIndex deviceIndex = m_core->deviceModel()->index( m_ui->deviceComboBox->currentIndex(), 0 );
@@ -297,7 +315,7 @@ PartitionPage::onNewVolumeGroupClicked()
         // is needed to set the current index in deviceComboBox as the previous one
         int previousIndex = m_ui->deviceComboBox->findData( previousIndexDeviceData, Qt::ToolTipRole );
 
-        m_ui->deviceComboBox->setCurrentIndex( ( previousIndex < 0  ) ? 0 : previousIndex );
+        m_ui->deviceComboBox->setCurrentIndex( ( previousIndex < 0 ) ? 0 : previousIndex );
         updateFromCurrentDevice();
     }
 
@@ -317,15 +335,16 @@ PartitionPage::onResizeVolumeGroupClicked()
 
     for ( const Partition* p : m_core->lvmPVs() )
         if ( !m_core->isInVG( p ) )
+        {
             availablePVs << p;
+        }
 
-    QPointer< ResizeVolumeGroupDialog > dlg = new ResizeVolumeGroupDialog( device,
-                                                                           availablePVs,
-                                                                           selectedPVs,
-                                                                           this );
+    QPointer< ResizeVolumeGroupDialog > dlg = new ResizeVolumeGroupDialog( device, availablePVs, selectedPVs, this );
 
     if ( dlg->exec() == QDialog::Accepted )
+    {
         m_core->resizeVolumeGroup( device, selectedPVs );
+    }
 
     delete dlg;
 }
@@ -368,14 +387,11 @@ PartitionPage::onCreateClicked()
     Q_ASSERT( partition );
 
     if ( !checkCanCreate( model->device() ) )
+    {
         return;
+    }
 
-    CreatePartitionDialog dlg(
-        model->device(),
-        partition->parent(),
-        nullptr,
-        getCurrentUsedMountpoints(),
-        this );
+    CreatePartitionDialog dlg( model->device(), partition->parent(), nullptr, getCurrentUsedMountpoints(), this );
     dlg.initFromFreeSpace( partition );
     if ( dlg.exec() == QDialog::Accepted )
     {
@@ -395,10 +411,13 @@ PartitionPage::onEditClicked()
     Q_ASSERT( partition );
 
     if ( CalamaresUtils::Partition::isPartitionNew( partition ) )
+    {
         updatePartitionToCreate( model->device(), partition );
+    }
     else
+    {
         editExistingPartition( model->device(), partition );
-
+    }
 }
 
 void
@@ -419,18 +438,18 @@ void
 PartitionPage::onRevertClicked()
 {
     ScanningDialog::run(
-        QtConcurrent::run( [ this ]
-        {
+        QtConcurrent::run( [this] {
             QMutexLocker locker( &m_revertMutex );
 
             int oldIndex = m_ui->deviceComboBox->currentIndex();
             m_core->revertAllDevices();
-            m_ui->deviceComboBox->setCurrentIndex( ( oldIndex < 0 )  ? 0 : oldIndex );
+            m_ui->deviceComboBox->setCurrentIndex( ( oldIndex < 0 ) ? 0 : oldIndex );
             updateFromCurrentDevice();
         } ),
-        [ this ]{
+        [this] {
             m_lastSelectedBootLoaderIndex = -1;
-            if( m_ui->bootLoaderComboBox->currentIndex() < 0 ) {
+            if ( m_ui->bootLoaderComboBox->currentIndex() < 0 )
+            {
                 m_ui->bootLoaderComboBox->setCurrentIndex( 0 );
             }
         },
@@ -442,7 +461,9 @@ PartitionPage::onPartitionViewActivated()
 {
     QModelIndex index = m_ui->partitionTreeView->currentIndex();
     if ( !index.isValid() )
+    {
         return;
+    }
 
     const PartitionModel* model = static_cast< const PartitionModel* >( index.model() );
     Q_ASSERT( model );
@@ -455,9 +476,13 @@ PartitionPage::onPartitionViewActivated()
     // action from multiple UI elements in this page, so it does not feel worth
     // the price.
     if ( CalamaresUtils::Partition::isPartitionFreeSpace( partition ) )
+    {
         m_ui->createButton->click();
+    }
     else
+    {
         m_ui->editButton->click();
+    }
 }
 
 void
@@ -466,11 +491,8 @@ PartitionPage::updatePartitionToCreate( Device* device, Partition* partition )
     QStringList mountPoints = getCurrentUsedMountpoints();
     mountPoints.removeOne( PartitionInfo::mountPoint( partition ) );
 
-    QPointer< CreatePartitionDialog > dlg = new CreatePartitionDialog( device,
-                                                                       partition->parent(),
-                                                                       partition,
-                                                                       mountPoints,
-                                                                       this );
+    QPointer< CreatePartitionDialog > dlg
+        = new CreatePartitionDialog( device, partition->parent(), partition, mountPoints, this );
     dlg->initFromPartitionToCreate( partition );
     if ( dlg->exec() == QDialog::Accepted )
     {
@@ -487,9 +509,12 @@ PartitionPage::editExistingPartition( Device* device, Partition* partition )
     QStringList mountPoints = getCurrentUsedMountpoints();
     mountPoints.removeOne( PartitionInfo::mountPoint( partition ) );
 
-    QPointer<EditExistingPartitionDialog> dlg = new EditExistingPartitionDialog( device, partition, mountPoints, this );
+    QPointer< EditExistingPartitionDialog > dlg
+        = new EditExistingPartitionDialog( device, partition, mountPoints, this );
     if ( dlg->exec() == QDialog::Accepted )
+    {
         dlg->applyChanges( m_core );
+    }
     delete dlg;
 }
 
@@ -497,11 +522,15 @@ void
 PartitionPage::updateBootLoaderInstallPath()
 {
     if ( m_isEfi || !m_ui->bootLoaderComboBox->isVisible() )
+    {
         return;
+    }
 
     QVariant var = m_ui->bootLoaderComboBox->currentData( BootLoaderModel::BootLoaderPathRole );
     if ( !var.isValid() )
+    {
         return;
+    }
     cDebug() << "PartitionPage::updateBootLoaderInstallPath" << var.toString();
     m_core->setBootLoaderInstallPath( var.toString() );
 }
@@ -516,7 +545,7 @@ PartitionPage::updateSelectedBootLoaderIndex()
 void
 PartitionPage::restoreSelectedBootLoader()
 {
-    Calamares::restoreSelectedBootLoader( *(m_ui->bootLoaderComboBox), m_core->bootLoaderInstallPath() );
+    Calamares::restoreSelectedBootLoader( *( m_ui->bootLoaderComboBox ), m_core->bootLoaderInstallPath() );
 }
 
 
@@ -525,13 +554,17 @@ PartitionPage::updateFromCurrentDevice()
 {
     QModelIndex index = m_core->deviceModel()->index( m_ui->deviceComboBox->currentIndex(), 0 );
     if ( !index.isValid() )
+    {
         return;
+    }
 
     Device* device = m_core->deviceModel()->deviceForIndex( index );
 
     QAbstractItemModel* oldModel = m_ui->partitionTreeView->model();
     if ( oldModel )
+    {
         disconnect( oldModel, nullptr, this, nullptr );
+    }
 
     PartitionModel* model = m_core->partitionModelForDevice( device );
     m_ui->partitionBarsView->setModel( model );
@@ -540,10 +573,8 @@ PartitionPage::updateFromCurrentDevice()
     m_ui->partitionTreeView->expandAll();
 
     // Make all views use the same selection model.
-    if ( m_ui->partitionBarsView->selectionModel() !=
-         m_ui->partitionTreeView->selectionModel() ||
-         m_ui->partitionBarsView->selectionModel() !=
-         m_ui->partitionLabelsView->selectionModel() )
+    if ( m_ui->partitionBarsView->selectionModel() != m_ui->partitionTreeView->selectionModel()
+         || m_ui->partitionBarsView->selectionModel() != m_ui->partitionLabelsView->selectionModel() )
     {
         // Tree view
         QItemSelectionModel* selectionModel = m_ui->partitionTreeView->selectionModel();
@@ -559,14 +590,17 @@ PartitionPage::updateFromCurrentDevice()
     // This is necessary because even with the same selection model it might happen that
     // a !=0 column is selected in the tree view, which for some reason doesn't trigger a
     // timely repaint in the bars view.
-    connect( m_ui->partitionBarsView->selectionModel(), &QItemSelectionModel::currentChanged,
-             this, [=]
-    {
-        QModelIndex selectedIndex = m_ui->partitionBarsView->selectionModel()->currentIndex();
-        selectedIndex = selectedIndex.sibling( selectedIndex.row(), 0 );
-        m_ui->partitionBarsView->setCurrentIndex( selectedIndex );
-        m_ui->partitionLabelsView->setCurrentIndex( selectedIndex );
-    }, Qt::UniqueConnection );
+    connect(
+        m_ui->partitionBarsView->selectionModel(),
+        &QItemSelectionModel::currentChanged,
+        this,
+        [=] {
+            QModelIndex selectedIndex = m_ui->partitionBarsView->selectionModel()->currentIndex();
+            selectedIndex = selectedIndex.sibling( selectedIndex.row(), 0 );
+            m_ui->partitionBarsView->setCurrentIndex( selectedIndex );
+            m_ui->partitionLabelsView->setCurrentIndex( selectedIndex );
+        },
+        Qt::UniqueConnection );
 
     // Must be done here because we need to have a model set to define
     // individual column resize mode
@@ -577,11 +611,9 @@ PartitionPage::updateFromCurrentDevice()
     updateButtons();
     // Establish connection here because selection model is destroyed when
     // model changes
-    connect( m_ui->partitionTreeView->selectionModel(), &QItemSelectionModel::currentChanged,
-             [ this ]( const QModelIndex&, const QModelIndex& )
-    {
-        updateButtons();
-    } );
+    connect( m_ui->partitionTreeView->selectionModel(),
+             &QItemSelectionModel::currentChanged,
+             [this]( const QModelIndex&, const QModelIndex& ) { updateButtons(); } );
     connect( model, &QAbstractItemModel::modelReset, this, &PartitionPage::onPartitionModelReset );
 }
 
@@ -597,7 +629,8 @@ void
 PartitionPage::updateBootLoaderIndex()
 {
     // set bootloader back to user selected index
-    if ( m_lastSelectedBootLoaderIndex >= 0 && m_ui->bootLoaderComboBox->count() ) {
+    if ( m_lastSelectedBootLoaderIndex >= 0 && m_ui->bootLoaderComboBox->count() )
+    {
         m_ui->bootLoaderComboBox->setCurrentIndex( m_lastSelectedBootLoaderIndex );
     }
 }
@@ -605,10 +638,11 @@ PartitionPage::updateBootLoaderIndex()
 QStringList
 PartitionPage::getCurrentUsedMountpoints()
 {
-    QModelIndex index = m_core->deviceModel()->index(
-                            m_ui->deviceComboBox->currentIndex(), 0 );
+    QModelIndex index = m_core->deviceModel()->index( m_ui->deviceComboBox->currentIndex(), 0 );
     if ( !index.isValid() )
+    {
         return QStringList();
+    }
 
     Device* device = m_core->deviceModel()->deviceForIndex( index );
     QStringList mountPoints;
@@ -617,7 +651,9 @@ PartitionPage::getCurrentUsedMountpoints()
     {
         const QString& mountPoint = PartitionInfo::mountPoint( partition );
         if ( !mountPoint.isEmpty() )
+        {
             mountPoints << mountPoint;
+        }
     }
 
     return mountPoints;
@@ -630,7 +666,7 @@ PartitionPage::selectedDeviceIndex()
 }
 
 void
-PartitionPage::selectDeviceByIndex ( int index )
+PartitionPage::selectDeviceByIndex( int index )
 {
-        m_ui->deviceComboBox->setCurrentIndex( index );
+    m_ui->deviceComboBox->setCurrentIndex( index );
 }
