@@ -1,29 +1,20 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
- *   Copyright 2019-2020, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2014-2015 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
+ *   SPDX-FileCopyrightText: 2019-2020 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "ReplaceWidget.h"
 #include "ui_ReplaceWidget.h"
 
 #include "core/DeviceModel.h"
-#include "core/PartitionCoreModule.h"
 #include "core/PartitionActions.h"
+#include "core/PartitionCoreModule.h"
 #include "core/PartitionInfo.h"
 
 #include "Branding.h"
@@ -41,9 +32,7 @@
 using CalamaresUtils::Partition::untranslatedFS;
 using CalamaresUtils::Partition::userVisibleFS;
 
-ReplaceWidget::ReplaceWidget( PartitionCoreModule* core,
-                              QComboBox* devicesComboBox,
-                              QWidget* parent )
+ReplaceWidget::ReplaceWidget( PartitionCoreModule* core, QComboBox* devicesComboBox, QWidget* parent )
     : QWidget( parent )
     , m_ui( new Ui_ReplaceWidget )
     , m_core( core )
@@ -57,20 +46,15 @@ ReplaceWidget::ReplaceWidget( PartitionCoreModule* core,
     m_ui->bootStatusLabel->clear();
 
     updateFromCurrentDevice( devicesComboBox );
-    connect( devicesComboBox, &QComboBox::currentTextChanged,
-             this, [=]( const QString& /* text */ )
-    {
+    connect( devicesComboBox, &QComboBox::currentTextChanged, this, [=]( const QString& /* text */ ) {
         updateFromCurrentDevice( devicesComboBox );
     } );
 
-    CALAMARES_RETRANSLATE(
-        onPartitionSelected();
-    )
+    CALAMARES_RETRANSLATE( onPartitionSelected(); )
 }
 
 
-ReplaceWidget::~ReplaceWidget()
-{}
+ReplaceWidget::~ReplaceWidget() {}
 
 
 bool
@@ -100,24 +84,25 @@ ReplaceWidget::applyChanges()
         {
             Device* dev = model->device();
 
-            PartitionActions::doReplacePartition(
-                m_core, dev, partition,
-                { gs->value( "defaultFileSystemType" ).toString(), QString() } );
+            PartitionActions::doReplacePartition( m_core,
+                                                  dev,
+                                                  partition,
+                                                  { gs->value( "defaultPartitionTableType" ).toString(),
+                                                    gs->value( "defaultFileSystemType" ).toString(),
+                                                    QString() } );
 
             if ( m_isEfi )
             {
                 QList< Partition* > efiSystemPartitions = m_core->efiSystemPartitions();
                 if ( efiSystemPartitions.count() == 1 )
                 {
-                    PartitionInfo::setMountPoint(
-                            efiSystemPartitions.first(),
-                            gs->value( "efiSystemPartition" ).toString() );
+                    PartitionInfo::setMountPoint( efiSystemPartitions.first(),
+                                                  gs->value( "efiSystemPartition" ).toString() );
                 }
                 else if ( efiSystemPartitions.count() > 1 )
                 {
-                    PartitionInfo::setMountPoint(
-                            efiSystemPartitions.at( m_ui->bootComboBox->currentIndex() ),
-                            gs->value( "efiSystemPartition" ).toString() );
+                    PartitionInfo::setMountPoint( efiSystemPartitions.at( m_ui->bootComboBox->currentIndex() ),
+                                                  gs->value( "efiSystemPartition" ).toString() );
                 }
             }
 
@@ -131,7 +116,9 @@ void
 ReplaceWidget::onPartitionSelected()
 {
     if ( Calamares::JobQueue::instance()->globalStorage()->value( "firmwareType" ) == "efi" )
+    {
         m_isEfi = true;
+    }
 
     const auto* branding = Calamares::Branding::instance();
     if ( m_ui->partitionTreeView->currentIndex() == QModelIndex() )
@@ -146,24 +133,20 @@ ReplaceWidget::onPartitionSelected()
     }
 
     bool ok = false;
-    double requiredSpaceB = Calamares::JobQueue::instance()
-                            ->globalStorage()
-                            ->value( "requiredStorageGiB" )
-                            .toDouble( &ok ) * 1024 * 1024 * 1024;
+    double requiredSpaceB
+        = Calamares::JobQueue::instance()->globalStorage()->value( "requiredStorageGiB" ).toDouble( &ok ) * 1024 * 1024
+        * 1024;
 
     PartitionModel* model = qobject_cast< PartitionModel* >( m_ui->partitionTreeView->model() );
     if ( model && ok )
     {
-        const QStringList osproberLines = Calamares::JobQueue::instance()
-                                    ->globalStorage()
-                                    ->value( "osproberLines" ).toStringList();
+        const QStringList osproberLines
+            = Calamares::JobQueue::instance()->globalStorage()->value( "osproberLines" ).toStringList();
 
         Partition* partition = model->partitionForIndex( m_ui->partitionTreeView->currentIndex() );
-        if ( !partition ||
-             partition->state() != KPM_PARTITION_STATE(None) )
+        if ( !partition || partition->state() != KPM_PARTITION_STATE( None ) )
         {
-            updateStatus( CalamaresUtils::Fail,
-                          tr( "The selected item does not appear to be a valid partition." ) );
+            updateStatus( CalamaresUtils::Fail, tr( "The selected item does not appear to be a valid partition." ) );
             setNextEnabled( false );
             return;
         }
@@ -173,7 +156,7 @@ ReplaceWidget::onPartitionSelected()
             updateStatus( CalamaresUtils::Fail,
                           tr( "%1 cannot be installed on empty space. Please select an "
                               "existing partition." )
-                          .arg( branding->versionedName() ) );
+                              .arg( branding->versionedName() ) );
             setNextEnabled( false );
             return;
         }
@@ -183,7 +166,7 @@ ReplaceWidget::onPartitionSelected()
             updateStatus( CalamaresUtils::Fail,
                           tr( "%1 cannot be installed on an extended partition. Please select an "
                               "existing primary or logical partition." )
-                          .arg( branding->versionedName() ) );
+                              .arg( branding->versionedName() ) );
             setNextEnabled( false );
             return;
         }
@@ -191,15 +174,14 @@ ReplaceWidget::onPartitionSelected()
         if ( partition->partitionPath().isEmpty() )
         {
             updateStatus( CalamaresUtils::Fail,
-                          tr( "%1 cannot be installed on this partition." )
-                          .arg( branding->versionedName() ) );
+                          tr( "%1 cannot be installed on this partition." ).arg( branding->versionedName() ) );
             setNextEnabled( false );
             return;
         }
 
         QString fsNameForUser = userVisibleFS( partition->fileSystem() );
         QString prettyName = tr( "Data partition (%1)" ).arg( fsNameForUser );
-        for ( const QString& line : osproberLines )
+        for ( const auto& line : osproberLines )
         {
             QStringList lineColumns = line.split( ':' );
 
@@ -208,20 +190,23 @@ ReplaceWidget::onPartitionSelected()
             {
                 QString osName;
                 if ( !lineColumns.value( 1 ).simplified().isEmpty() )
+                {
                     osName = lineColumns.value( 1 ).simplified();
+                }
                 else if ( !lineColumns.value( 2 ).simplified().isEmpty() )
+                {
                     osName = lineColumns.value( 2 ).simplified();
+                }
 
                 if ( osName.isEmpty() )
                 {
-                    prettyName = tr( "Unknown system partition (%1)" )
-                                 .arg( fsNameForUser );
+                    prettyName = tr( "Unknown system partition (%1)" ).arg( fsNameForUser );
                 }
                 else
                 {
-                    prettyName = tr ( "%1 system partition (%2)" )
-                                 .arg( osName.replace( 0, 1, osName.at( 0 ).toUpper() ) )
-                                 .arg( fsNameForUser );
+                    prettyName = tr( "%1 system partition (%2)" )
+                                     .arg( osName.replace( 0, 1, osName.at( 0 ).toUpper() ) )
+                                     .arg( fsNameForUser );
                 }
                 break;
             }
@@ -233,11 +218,10 @@ ReplaceWidget::onPartitionSelected()
                           tr( "<strong>%4</strong><br/><br/>"
                               "The partition %1 is too small for %2. Please select a partition "
                               "with capacity at least %3 GiB." )
-                          .arg( partition->partitionPath() )
-                          .arg( branding->versionedName() )
-                          .arg( requiredSpaceB / ( 1024. * 1024. * 1024. ),
-                                0, 'f', 1 )
-                          .arg( prettyName ) );
+                              .arg( partition->partitionPath() )
+                              .arg( branding->versionedName() )
+                              .arg( requiredSpaceB / ( 1024. * 1024. * 1024. ), 0, 'f', 1 )
+                              .arg( prettyName ) );
             setNextEnabled( false );
             return;
         }
@@ -257,8 +241,8 @@ ReplaceWidget::onPartitionSelected()
                                   "An EFI system partition cannot be found anywhere "
                                   "on this system. Please go back and use manual "
                                   "partitioning to set up %1." )
-                              .arg( branding->shortProductName() )
-                              .arg( prettyName ) );
+                                  .arg( branding->shortProductName() )
+                                  .arg( prettyName ) );
                 setNextEnabled( false );
             }
             else if ( efiSystemPartitions.count() == 1 )
@@ -267,15 +251,14 @@ ReplaceWidget::onPartitionSelected()
                               tr( "<strong>%3</strong><br/><br/>"
                                   "%1 will be installed on %2.<br/>"
                                   "<font color=\"red\">Warning: </font>all data on partition "
-                                  "%2 will be lost.")
-                                .arg( branding->versionedName() )
-                                .arg( partition->partitionPath() )
-                                .arg( prettyName ) );
+                                  "%2 will be lost." )
+                                  .arg( branding->versionedName() )
+                                  .arg( partition->partitionPath() )
+                                  .arg( prettyName ) );
                 m_ui->bootStatusLabel->show();
-                m_ui->bootStatusLabel->setText(
-                    tr( "The EFI system partition at %1 will be used for starting %2." )
-                        .arg( efiSystemPartitions.first()->partitionPath() )
-                        .arg( branding->shortProductName() ) );
+                m_ui->bootStatusLabel->setText( tr( "The EFI system partition at %1 will be used for starting %2." )
+                                                    .arg( efiSystemPartitions.first()->partitionPath() )
+                                                    .arg( branding->shortProductName() ) );
                 setNextEnabled( true );
             }
             else
@@ -284,10 +267,10 @@ ReplaceWidget::onPartitionSelected()
                               tr( "<strong>%3</strong><br/><br/>"
                                   "%1 will be installed on %2.<br/>"
                                   "<font color=\"red\">Warning: </font>all data on partition "
-                                  "%2 will be lost.")
-                                .arg( branding->versionedName() )
-                                .arg( partition->partitionPath() )
-                                .arg( prettyName ) );
+                                  "%2 will be lost." )
+                                  .arg( branding->versionedName() )
+                                  .arg( partition->partitionPath() )
+                                  .arg( prettyName ) );
                 m_ui->bootStatusLabel->show();
                 m_ui->bootStatusLabel->setText( tr( "EFI system partition:" ) );
                 m_ui->bootComboBox->show();
@@ -295,9 +278,10 @@ ReplaceWidget::onPartitionSelected()
                 {
                     Partition* efiPartition = efiSystemPartitions.at( i );
                     m_ui->bootComboBox->addItem( efiPartition->partitionPath(), i );
-                    if ( efiPartition->devicePath() == partition->devicePath() &&
-                         efiPartition->number() == 1 )
+                    if ( efiPartition->devicePath() == partition->devicePath() && efiPartition->number() == 1 )
+                    {
                         m_ui->bootComboBox->setCurrentIndex( i );
+                    }
                 }
                 setNextEnabled( true );
             }
@@ -308,10 +292,10 @@ ReplaceWidget::onPartitionSelected()
                           tr( "<strong>%3</strong><br/><br/>"
                               "%1 will be installed on %2.<br/>"
                               "<font color=\"red\">Warning: </font>all data on partition "
-                              "%2 will be lost.")
-                            .arg( branding->versionedName() )
-                            .arg( partition->partitionPath() )
-                            .arg( prettyName ) );
+                              "%2 will be lost." )
+                              .arg( branding->versionedName() )
+                              .arg( partition->partitionPath() )
+                              .arg( prettyName ) );
             setNextEnabled( true );
         }
     }
@@ -322,7 +306,9 @@ void
 ReplaceWidget::setNextEnabled( bool enabled )
 {
     if ( enabled == m_nextEnabled )
+    {
         return;
+    }
 
     m_nextEnabled = enabled;
     emit nextStatusChanged( enabled );
@@ -333,27 +319,29 @@ void
 ReplaceWidget::updateStatus( CalamaresUtils::ImageType imageType, const QString& text )
 {
     int iconSize = CalamaresUtils::defaultFontHeight() * 6;
-    m_ui->selectedIconLabel->setPixmap( CalamaresUtils::defaultPixmap( imageType,
-                                                                       CalamaresUtils::Original,
-                                                                       QSize( iconSize, iconSize ) ) );
+    m_ui->selectedIconLabel->setPixmap(
+        CalamaresUtils::defaultPixmap( imageType, CalamaresUtils::Original, QSize( iconSize, iconSize ) ) );
     m_ui->selectedIconLabel->setFixedHeight( iconSize );
     m_ui->selectedStatusLabel->setText( text );
 }
 
 
-
 void
 ReplaceWidget::updateFromCurrentDevice( QComboBox* devicesComboBox )
 {
     QModelIndex index = m_core->deviceModel()->index( devicesComboBox->currentIndex(), 0 );
     if ( !index.isValid() )
+    {
         return;
+    }
 
     Device* device = m_core->deviceModel()->deviceForIndex( index );
 
     QAbstractItemModel* oldModel = m_ui->partitionTreeView->model();
     if ( oldModel )
+    {
         disconnect( oldModel, nullptr, this, nullptr );
+    }
 
     PartitionModel* model = m_core->partitionModelForDevice( device );
     m_ui->partitionTreeView->setModel( model );
@@ -368,8 +356,10 @@ ReplaceWidget::updateFromCurrentDevice( QComboBox* devicesComboBox )
     //updateButtons();
     // Establish connection here because selection model is destroyed when
     // model changes
-    connect( m_ui->partitionTreeView->selectionModel(), &QItemSelectionModel::currentRowChanged,
-             this, &ReplaceWidget::onPartitionViewActivated );
+    connect( m_ui->partitionTreeView->selectionModel(),
+             &QItemSelectionModel::currentRowChanged,
+             this,
+             &ReplaceWidget::onPartitionViewActivated );
 
     connect( model, &QAbstractItemModel::modelReset, this, &ReplaceWidget::onPartitionModelReset );
 }
@@ -380,7 +370,9 @@ ReplaceWidget::onPartitionViewActivated()
 {
     QModelIndex index = m_ui->partitionTreeView->currentIndex();
     if ( !index.isValid() )
+    {
         return;
+    }
 
     const PartitionModel* model = static_cast< const PartitionModel* >( index.model() );
     Q_ASSERT( model );
