@@ -1,19 +1,10 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2017-2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "TrackingJobs.h"
@@ -46,12 +37,6 @@ TrackingInstallJob::prettyName() const
     return tr( "Installation feedback" );
 }
 
-QString
-TrackingInstallJob::prettyDescription() const
-{
-    return prettyName();
-}
-
 QString
 TrackingInstallJob::prettyStatusMessage() const
 {
@@ -86,12 +71,6 @@ TrackingMachineUpdateManagerJob::prettyName() const
     return tr( "Machine feedback" );
 }
 
-QString
-TrackingMachineUpdateManagerJob::prettyDescription() const
-{
-    return prettyName();
-}
-
 QString
 TrackingMachineUpdateManagerJob::prettyStatusMessage() const
 {
@@ -143,12 +122,6 @@ TrackingKUserFeedbackJob::prettyName() const
     return tr( "KDE user feedback" );
 }
 
-QString
-TrackingKUserFeedbackJob::prettyDescription() const
-{
-    return prettyName();
-}
-
 QString
 TrackingKUserFeedbackJob::prettyStatusMessage() const
 {
